@@ -12,9 +12,7 @@ import { globalVariables } from "../components/styles.css";
 
 @customElement("sb-dual-select-host-provider")
 export class SbHostProvider extends LitElement {
-    static get styles() {
-        return globalVariables;
-    }
+    static styles = globalVariables;
 
     render() {
         return html`<slot></slot>`;
