@@ -1,22 +1,5 @@
 import { createContext, useContext } from "react";
-
-/**
- * A parsed JSON module containing MDX content and metadata from ESBuild.
- */
-export interface MDXModule {
-    /**
-     * The Markdown content of the module.
-     */
-    content: string;
-    /**
-     * The public path of the module, typically identical to the docs page path.
-     */
-    publicPath?: string;
-    /**
-     * The public directory of the module, used to resolve relative links.
-     */
-    publicDirectory?: string;
-}
+import type { MDXModule } from "~docs/types";
 
 /**
  * Fetches an MDX module from a URL or ESBuild static asset.
